{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Filter single sample sv vcf from depth callers(cnvkit/cnvnator)",
            "inputs": [
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "id": "#main/deletion_depth"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "id": "#main/duplication_depth"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/min_sv_size"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/output_vcf_name"
                },
                {
                    "type": "File",
                    "id": "#main/sv_vcf"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/vcf_source/cnvkit",
                                "#main/vcf_source/cnvnator"
                            ]
                        }
                    ],
                    "id": "#main/vcf_source"
                }
            ],
            "steps": [
                {
                    "run": "#filter_sv_vcf_depth.cwl",
                    "in": [
                        {
                            "source": "#main/deletion_depth",
                            "id": "#main/depth_filter/deletion_depth"
                        },
                        {
                            "source": "#main/duplication_depth",
                            "id": "#main/depth_filter/duplication_depth"
                        },
                        {
                            "source": "#main/size_filter/filtered_sv_vcf",
                            "id": "#main/depth_filter/input_vcf"
                        },
                        {
                            "source": "#main/output_vcf_name",
                            "id": "#main/depth_filter/output_vcf_name"
                        },
                        {
                            "source": "#main/vcf_source",
                            "id": "#main/depth_filter/vcf_source"
                        }
                    ],
                    "out": [
                        "#main/depth_filter/filtered_sv_vcf"
                    ],
                    "id": "#main/depth_filter"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/depth_filter/filtered_sv_vcf",
                            "id": "#main/filtered_vcf_bgzip/file"
                        }
                    ],
                    "out": [
                        "#main/filtered_vcf_bgzip/bgzipped_file"
                    ],
                    "id": "#main/filtered_vcf_bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/filtered_vcf_bgzip/bgzipped_file",
                            "id": "#main/filtered_vcf_index/vcf"
                        }
                    ],
                    "out": [
                        "#main/filtered_vcf_index/indexed_vcf"
                    ],
                    "id": "#main/filtered_vcf_index"
                },
                {
                    "run": "#filter_sv_vcf_size.cwl",
                    "in": [
                        {
                            "source": "#main/sv_vcf",
                            "id": "#main/size_filter/input_vcf"
                        },
                        {
                            "default": "min_len",
                            "id": "#main/size_filter/size_method"
                        },
                        {
                            "source": "#main/min_sv_size",
                            "id": "#main/size_filter/sv_size"
                        }
                    ],
                    "out": [
                        "#main/size_filter/filtered_sv_vcf"
                    ],
                    "id": "#main/size_filter"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/filtered_vcf_index/indexed_vcf",
                    "id": "#main/filtered_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "filter_sv_vcf_depth.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.9"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "filter_sv_vcf_depth.sh",
                            "entry": "#!/bin/bash\nset -eou pipefail\n\nINPUT_VCF=\"$1\"\nOUTPUT_VCF=\"$2\"\nDEL_DEPTH=\"$3\"\nDUP_DEPTH=\"$4\"\nVCF_SOURCE=\"$5\"\n\nif [ \"$VCF_SOURCE\" == \"cnvnator\" ]; then\n  echo \"Running filter for cnvnator vcf\"\n  filter_expression=\"(natorRD>$DUP_DEPTH | natorRD<$DEL_DEPTH)\"\nelif [ \"$VCF_SOURCE\" ==  \"cnvkit\" ]; then\n  echo \"Running filter for cnvkit vcf\"\n  filter_expression=\"(FOLD_CHANGE>$DUP_DEPTH | FOLD_CHANGE<$DEL_DEPTH)\"\nelif [ \"$VCF_SOURCE\" ==  \"duphold\" ]; then\n  echo \"Running filter for vcf annotated by duphold\"\n  filter_expression=\"((SVTYPE='DEL' & FMT/DHFFC[0] < $DEL_DEPTH) | (SVTYPE='DUP' & FMT/DHBFC[0] > $DUP_DEPTH) | SVTYPE='BND' | SVTYPE='INS' | SVTYPE='INV')\"\nelse\n  echo \"vcf source: '$VCF_SOURCE' is not supported for SV filtering\"\n  exit 1\nfi\n/opt/bcftools/bin/bcftools filter \"$INPUT_VCF\" -o \"$OUTPUT_VCF\" -i \"$filter_expression\"\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "default": 0.75,
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Depth for deletions must be less than this cutoff to pass the filter.",
                    "id": "#filter_sv_vcf_depth.cwl/deletion_depth"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "default": 1.25,
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "Depth for duplications must be greater than this cutoff to pass the filter.",
                    "id": "#filter_sv_vcf_depth.cwl/duplication_depth"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "vcf file to filter",
                    "id": "#filter_sv_vcf_depth.cwl/input_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "filtered_cnv.vcf",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "output vcf file name",
                    "id": "#filter_sv_vcf_depth.cwl/output_vcf_name"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#filter_sv_vcf_depth.cwl/vcf_source/cnvnator",
                                "#filter_sv_vcf_depth.cwl/vcf_source/cnvkit",
                                "#filter_sv_vcf_depth.cwl/vcf_source/duphold"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "source caller of the vcf input file",
                    "id": "#filter_sv_vcf_depth.cwl/vcf_source"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_name)"
                    },
                    "id": "#filter_sv_vcf_depth.cwl/filtered_sv_vcf"
                }
            ],
            "id": "#filter_sv_vcf_depth.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "filter_sv_vcf_size.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.9"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "filter_sv_vcf_size.sh",
                            "entry": "#!/bin/bash\nset -eou pipefail\n\nINPUT_VCF=\"$1\"\nOUTPUT_VCF=\"$2\"\nSV_SIZE=\"$3\"\nFILTER_METHOD=\"$4\"\n\nif [ \"$FILTER_METHOD\" == \"max_len\" ]; then\n  echo \"Running filter for max size svs\"\n  filter_expression=\"ABS(SVLEN) <= $SV_SIZE\"\nelif [ \"$FILTER_METHOD\" ==  \"min_len\" ]; then\n  echo \"Running filter for min size svs\"\n  filter_expression=\"ABS(SVLEN) >= $SV_SIZE\"\nelse\n  echo \"Filter method: '$FILTER_METHOD' is not supported for size SV filtering\"\n  exit 1\nfi\n/opt/bcftools/bin/bcftools filter \"$INPUT_VCF\" -o \"$OUTPUT_VCF\" -i \"$filter_expression\"\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "vcf file to filter",
                    "id": "#filter_sv_vcf_size.cwl/input_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "filtered_sv_size.vcf",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "output vcf file name",
                    "id": "#filter_sv_vcf_size.cwl/output_vcf_name"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#filter_sv_vcf_size.cwl/size_method/max_len",
                                "#filter_sv_vcf_size.cwl/size_method/min_len"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "method for size filtering",
                    "id": "#filter_sv_vcf_size.cwl/size_method"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 50000,
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "size in bp used for filtering",
                    "id": "#filter_sv_vcf_size.cwl/sv_size"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_name)"
                    },
                    "id": "#filter_sv_vcf_size.cwl/filtered_sv_vcf"
                }
            ],
            "id": "#filter_sv_vcf_size.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
